@@ -8,7 +8,7 @@ use Error::Pure qw(err);
 use Indent;
 use Indent::Word;
 use Indent::Block;
-use List::MoreUtils qw(none);
+use List::Util qw(none);
 use Readonly;
 use Tags::Utils qw(encode_attr_entities encode_char_entities);
 use Tags::Utils::Preserve;
@@ -19,7 +19,7 @@ Readonly::Scalar my $LAST_INDEX => -1;
 Readonly::Scalar my $LINE_SIZE => 79;
 Readonly::Scalar my $SPACE => q{ };
 
-our $VERSION = 0.09;
+our $VERSION = 0.10;
 
 # Finalize Tags output.
 sub finalize {
@@ -800,7 +800,7 @@ L<Error::Pure>,
 L<Indent>,
 L<Indent::Word>,
 L<Indent::Block>,
-L<List::MoreUtils>,
+L<List::Util>,
 L<Readonly>,
 L<Tags::Utils::Preserve>.
 
@@ -834,12 +834,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2011-2022 Michal Josef Špaček
+© 2011-2023 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.09
+0.10
 
 =cut
